#!/bin/bash -xe

# Certificate Authority config
CA_CERTIFICATE_DIRECTORY=/etc/kubernetes/pki
CA_CERTIFICATE_FILE_PATH=$CA_CERTIFICATE_DIRECTORY/ca.crt
mkdir -p $CA_CERTIFICATE_DIRECTORY
echo "${cluster_auth_base64}" | base64 -d >$CA_CERTIFICATE_FILE_PATH

# Authentication
INTERNAL_IP=$(curl -s http://169.254.169.254/latest/meta-data/local-ipv4)
sed -i s,MASTER_ENDPOINT,${endpoint},g /var/lib/kubelet/kubeconfig
sed -i s,CLUSTER_NAME,${cluster_name},g /var/lib/kubelet/kubeconfig
sed -i s,REGION,${region},g /etc/systemd/system/kubelet.service
sed -i s,MAX_PODS,${max_pod_count},g /etc/systemd/system/kubelet.service
sed -i s,MASTER_ENDPOINT,${endpoint},g /etc/systemd/system/kubelet.service
sed -i s,INTERNAL_IP,$INTERNAL_IP,g /etc/systemd/system/kubelet.service

# DNS cluster configuration
DNS_CLUSTER_IP=10.100.0.10
if [[ $INTERNAL_IP == 10.* ]]; then DNS_CLUSTER_IP=${alt_dns_cluster_ip}; fi
sed -i s,DNS_CLUSTER_IP,$DNS_CLUSTER_IP,g /etc/systemd/system/kubelet.service
sed -i s,CERTIFICATE_AUTHORITY_FILE,$CA_CERTIFICATE_FILE_PATH,g /var/lib/kubelet/kubeconfig
sed -i s,CLIENT_CA_FILE,$CA_CERTIFICATE_FILE_PATH,g /etc/systemd/system/kubelet.service

# start services
systemctl daemon-reload
systemctl restart kubelet

# Install cron
yum -y install crontabs
chkconfig crond on
service crond start

# Add Steamhaus user
adduser steamhaus
passwd -l steamhaus
mkdir -p /home/steamhaus/bin
mkdir -p /home/steamhaus/.ssh
chmod 700 /home/steamhaus/.ssh

# Ensure Steamhaus user has full passwordless root
echo "steamhaus ALL=(ALL)NOPASSWD:ALL" > /etc/sudoers.d/steamhaus
chmod 440 /etc/sudoers.d/steamhaus

# Create Steamhaus SSH credential update script
wget --no-check-certificate "https://gist.githubusercontent.com/chrisfu/87b642951aadafa62b99/raw/sh_pubkey_update.sh" -O /home/steamhaus/bin/sh_pubkey_update.sh
sed -i s,\`whoami\`,steamhaus,g /home/steamhaus/bin/sh_pubkey_update.sh
chmod 755 /home/steamhaus/bin/sh_pubkey_update.sh

# Perform first-time update of Steamhaus SSH credentials
/home/steamhaus/bin/sh_pubkey_update.sh
echo "0 1 * * * /home/steamhaus/bin/sh_pubkey_update.sh" > /var/spool/cron/steamhaus

# Ensure everything within Steamhaus home directory is owned by Steamhaus
chown -R steamhaus: /home/steamhaus/

# Allow user supplied userdata code
${additional_userdata}
